==> npm-niosz-log-2.5.5.tgz: package/index.js <==
// ****************************************************************************
// *** LOGGING SYSTEM *********************************************************
// ****************************************************************************
var jsonCore = require("npm-niosz-core-json");
// ****************************************************************************
var loggersList = [];
var getLoggerList = function() {
    var resp = [];
    resp.push(...loggersList);
    return resp;
};
// ****************************************************************************
var excludeList = [];
var getExcludeList = function() {
    return excludeList;
};
var clearExcludeList = function() {
    excludeList = [];
};
var addExclusion = function(s) {
    if (typeof s == "string" && s.trim() != "") {
        s = s.trim();
        if (excludeList.indexOf(s)<0) excludeList.push(s);
    }
};
var removeExclusion = function(s) {
    if (typeof s == "string" && s.trim() != "") {
        s = s.trim();
        if (excludeList.indexOf(s)>=0) {
            excludeList = excludeList.filter((exclusion)=>{
                return exclusion != s;
            });
        }
    }
};
var addExclusions = function(a) {
    if (typeof a == "object" && Array.isArray(a) && a.length>0) {
        a.forEach((s)=>{
            addExclusion(s);
        });
    }
};
var removeExclusions = function(a) {
    if (typeof a == "object" && Array.isArray(a) && a.length>0) {
        a.forEach((s)=>{
            removeExclusion(s);
        });
    }
};
// ****************************************************************************
var azureContext = null;
var setAzureContext = function(context) {
    azureContext = context;
};
// ****************************************************************************
var appName = "node";
var setAppName = function(name) {
    if ( typeof name != "string" || name.trim() == "" )
        throw "FATAL LOG ERROR : LOG APP NAME NOT DEFINED";
    name = name.trim();
    appName = name;
};
var getAppName = function() {
    return appName;
};
// ****************************************************************************
var logLevels = [ "TRACE", "DEBUG", "INFOR", "WARNG", "ERROR", "FATAL" ];
var logLevel = 2;
var setLevel = function(level) {
    if (typeof level === "number") {
        if (level>=0 && level<logLevels.length)
            logLevel = level;
    } else {
        level = level.toString().trim().toUpperCase();
        level = logLevels.indexOf(level);
        if (level>=0) logLevel = level;
    }
};
var getLevel = function() {
    return logLevels[logLevel];
};
// ****************************************************************************
var logMessageDate = function() {
    return (new Date()).toISOString().substring(0,23).replace("T"," ");
};
var logMessageApp = function() {
    return appName + ":" + process.pid + ":" + process.ppid;
}
var logMessage = function(params,name,level,multiLines) {
    if ( level >= logLevel && excludeList.indexOf(name) < 0 ) {

        // decoding message
        var message = [];
        for (var i=0;i<params.length;i++) {
            var mex = jsonCore.stringify(params[i],true);
            if (jsonCore.isString(mex)) {
                if (mex.startsWith('"') && mex.endsWith('"'))
                    mex = mex.substring(1,mex.length-1);
            } else mex = "" + mex;
            message.push(mex);
        }    
        message = message.join(" ");

        // finalizing message
        if (!multiLines)
            try { message = message.trim().replace(/[\s]+/gm," "); } catch {};
        var logMessage = "[" + logMessageDate() + "] <" + logMessageApp() + "> {" + name + "} (" + logLevels[level] + ") " + message;
        if (azureContext != null && azureContext.log != null) {
            try {
                var logAzureMessage = "(" + level + ") <" + logMessageApp() + "> {" + name + "} " + message;
                var logFunction = azureContext.log.info;
                if (level<2) logFunction = azureContext.log.verbose;
                else if (level == 3) logFunction = azureContext.log.warn;
                else if (level > 3) logFunction = azureContext.log.error;
                logFunction(logAzureMessage);
            } catch {
                console.log(logMessage);
            }
        } else console.log(logMessage);
    }
};
// ****************************************************************************
var newLog = function(name,multiLines) {
    if ( typeof name != "string" || name.trim() == "" )
        throw "FATAL LOG ERROR : LOG NAME NOT DEFINED";
    name = name.trim();
    if ( loggersList.indexOf(appName + "::" + name) >= 0)  {
        throw "FATAL LOG ERROR : LOG NAME (" + appName +"::" + name + ") ALREADY EXISTS!";
    }
    loggersList.push(appName + "::" + name);
    return {
        t : function() {
            var params = [];
            for (var i=0;i<arguments.length;i++) params.push(arguments[i]);
            return logMessage(params,name,0,multiLines);
        },
        d : function() {
            var params = [];
            for (var i=0;i<arguments.length;i++) params.push(arguments[i]);
            return logMessage(params,name,1,multiLines);
        },
        i : function() {
            var params = [];
            for (var i=0;i<arguments.length;i++) params.push(arguments[i]);
            return logMessage(params,name,2,multiLines);
        },
        w : function() {
            var params = [];
            for (var i=0;i<arguments.length;i++) params.push(arguments[i]);
            return logMessage(params,name,3,multiLines);
        },
        e : function() {
            var params = [];
            for (var i=0;i<arguments.length;i++) params.push(arguments[i]);
            return logMessage(params,name,4,multiLines);
        },
        f : function() {
            var params = [];
            for (var i=0;i<arguments.length;i++) params.push(arguments[i]);
            return logMessage(params,name,5,multiLines);
        }
    };
};
// ****************************************************************************
var LOG = {
    setAzureContext  : setAzureContext,
    setAppName       : setAppName,
    getAppName       : getAppName,
    setLevel         : setLevel,
    getLevel         : getLevel,
    getLoggerList    : getLoggerList,
    getExcludeList   : getExcludeList,
    clearExcludeList : clearExcludeList,
    addExclusion     : addExclusion,
    removeExclusion  : removeExclusion,
    addExclusions    : addExclusions,
    removeExclusions : removeExclusions,
    newLog           : newLog
};
// ****************************************************************************
module.exports = LOG;

==> npm-niosz-log-3.0.0.tgz: package/index.js <==
var initModule = function() {
// ****************************************************************************
// *** LOGGING SYSTEM *********************************************************
// ****************************************************************************
var jsonCore = require("npm-niosz-core-json");
// ****************************************************************************
var standardConsole = console;
var getStandardConsole = function() {
    return standardConsole;
};
var setStandardConsole = function(c) {
    standardConsole = (c && c.log) ? c : console;
};
// ****************************************************************************
var globalMultiLines = false;
var getGlobalMultiLines = function() {
    return globalMultiLines;
};
var setGlobalMultiLines = function (active) {
    globalMultiLines = (!active) ? false : true;
};
// ****************************************************************************
var loggersList = [];
var getLoggerList = function() {
    var resp = [];
    resp.push(...loggersList);
    return resp;
};
// ****************************************************************************
var excludeList = [];
var getExcludeList = function() {
    return excludeList;
};
var clearExcludeList = function() {
    excludeList = [];
};
var addExclusion = function(s) {
    if (typeof s == "string" && s.trim() != "") {
        s = s.trim();
        if (excludeList.indexOf(s)<0) excludeList.push(s);
    }
};
var removeExclusion = function(s) {
    if (typeof s == "string" && s.trim() != "") {
        s = s.trim();
        if (excludeList.indexOf(s)>=0) {
            excludeList = excludeList.filter((exclusion)=>{
                return exclusion != s;
            });
        }
    }
};
var addExclusions = function(a) {
    if (typeof a == "object" && Array.isArray(a) && a.length>0) {
        a.forEach((s)=>{
            addExclusion(s);
        });
    }
};
var removeExclusions = function(a) {
    if (typeof a == "object" && Array.isArray(a) && a.length>0) {
        a.forEach((s)=>{
            removeExclusion(s);
        });
    }
};
// ****************************************************************************
var azureContext = null;
var setAzureContext = function(context) {
    azureContext = context;
};
// ****************************************************************************
var appName = "node";
var setAppName = function(name) {
    if ( typeof name != "string" || name.trim() == "" )
        throw "FATAL LOG ERROR : LOG APP NAME NOT DEFINED";
    name = name.trim();
    appName = name;
};
var getAppName = function() {
    return appName;
};
// ****************************************************************************
var logLevels = [ "TRACE", "DEBUG", "INFOR", "WARNG", "ERROR", "FATAL" ];
var logLevel = 2;
var setLevel = function(level) {
    if (typeof level === "number") {
        if (level>=0 && level<logLevels.length)
            logLevel = level;
    } else {
        level = level.toString().trim().toUpperCase();
        level = logLevels.indexOf(level);
        if (level>=0) logLevel = level;
    }
};
var getLevel = function() {
    return logLevels[logLevel];
};
// ****************************************************************************
var logMessageDate = function() {
    return (new Date()).toISOString().substring(0,23).replace("T"," ");
};
var logMessageApp = function() {
    return appName + ":" + process.pid + ":" + process.ppid;
}
var logMessage = function(params,name,level) {
    if ( level >= logLevel && excludeList.indexOf(name) < 0 ) {

        // decoding message
        var message = [];
        for (var i=0;i<params.length;i++) {
            var mex = jsonCore.stringify(params[i],true);
            if (!jsonCore.isString(mex)) mex = "" + mex;
            message.push(mex);
        }
        if (message.length == 0) 
             message = "undefined";    
        else message = message.join(" ");

        // finalizing message
        if (!globalMultiLines)
            try { message = message.trim().replace(/[\s]+/gm," "); } catch {};
        var logMessage = "[" + logMessageDate() + "] <" + logMessageApp() + "> {" + name + "} (" + logLevels[level] + ") " + message;

        // logging system
        if (azureContext != null && azureContext.log != null) {
            // azure logging
            try {
                var logAzureMessage = "(" + level + ") <" + logMessageApp() + "> {" + name + "} " + message;
                var logFunction = azureContext.log.info;
                if (level<2) logFunction = azureContext.log.verbose;
                else if (level == 3) logFunction = azureContext.log.warn;
                else if (level > 3) logFunction = azureContext.log.error;
                logFunction(logAzureMessage);
            } catch {
                // standard system defined on error
                standardConsole.log(logMessage);
            }
        } else {
            // standard system defined
            standardConsole.log(logMessage);
        }
    }
};
// ****************************************************************************
var newLog = function(name) {
    if ( typeof name != "string" || name.trim() == "" )
        throw "FATAL LOG ERROR : LOG NAME NOT DEFINED";
    name = name.trim();
    if ( loggersList.indexOf(name) < 0) loggersList.push(name);
    var logFunction = function(level) {
        var logLevel = level;
        var logFn = function() {
            try {
                var params = [];
                for (var i=0;i<arguments.length;i++) params.push(arguments[i]);
                return logMessage(params,name,logLevel);
            } catch(e) {
                throw "FATAL LOG ERROR : " + e;
            }
        };
        return logFn;
    };
    return {
        t : logFunction(0),
        d : logFunction(1),
        i : logFunction(2),
        w : logFunction(3),
        e : logFunction(4),
        f : logFunction(5)
    };
};
// ***********************************************************************************
var pkgInfo = require("./package.json");
var logModuleInfo = function() {
    try {
        return pkgInfo.name+" (v"+pkgInfo.version+") with ["+jsonCore.moduleInfo()+"]";
    } catch(e) {
        throw "FATAL ERROR LOG MODULE INFO : " + e;
    }
};
// ****************************************************************************
var LOG = {
    moduleInfo          : logModuleInfo,
    getStandardConsole  : getStandardConsole,
    setStandardConsole  : setStandardConsole,
    setAzureContext     : setAzureContext,
    setAppName          : setAppName,
    getAppName          : getAppName,
    setLevel            : setLevel,
    getLevel            : getLevel,
    getGlobalMultiLines : getGlobalMultiLines,
    setGlobalMultiLines : setGlobalMultiLines,
    getLoggerList       : getLoggerList,
    getExcludeList      : getExcludeList,
    clearExcludeList    : clearExcludeList,
    addExclusion        : addExclusion,
    removeExclusion     : removeExclusion,
    addExclusions       : addExclusions,
    removeExclusions    : removeExclusions,
    newLog              : newLog,
    stringify           : jsonCore.stringify,
    parse               : jsonCore.parse,
    isString            : jsonCore.isString,
    logMessageApp       : logMessageApp,
    logMessageDate      : logMessageDate
};
// ***********************************************************************************
return LOG;
};
module.exports = initModule();
